easyboto
===========================================================

This readme has been autogenerated

.. image:: https://badge.fury.io/py/easyboto.png
    :target: https://badge.fury.io/py/easyboto

.. image:: https://pypip.in/d/easyboto/badge.png
    :target: https://pypi.python.org/pypi/easyboto

Installation
------------

Installation using pip::

    pip install easyboto

Usage
-----

*Usage instructions here*

Credits
-------

*Any credits here*

easyboto is packaged using seed_.

.. _seed: https://github.com/adamcharnock/seed/

